@@ -30,7 +30,7 @@ void usage(std::string const &progname)
     "                           (default `" <<
                                         Options::defaultPIDfile() << "')\n"
     "      --protocol spec    - spec: protocols handled with the `conntrack'\n"
-    "                           comand. Use colon separated combinations of\n"
+    "                           command. Use colon separated combinations of\n"
     "                           tcp, udp and icmp, or use `all' "
                                                             "(default: tcp)\n"
     "      --syslog-tag id    - id: identifier prefixed to syslog messages\n"
@@ -50,7 +50,7 @@ void usage(std::string const &progname)
     "                            raw: (default) seconds since the epoch;\n"
     "                            utc: date and time in UTC\n"
     "                            local: local date and time\n"
-    "      --verbose          - write additional information:\n"
+    "      --verbose (-V)     - write additional information:\n"
     "                               with --no-daemon: to stdout;\n"
     "                               with daemons and --no-syslog not "
                                                                 "specified:\n"
